<a id="packages.valory.skills.oracle_deployment_abci.dialogues"></a>

# packages.valory.skills.oracle`_`deployment`_`abci.dialogues

This module contains the classes required for dialogue management.

